==> aicli-99.0.202205091944.202103111306-py3-none-any.whl: ailib/redfish/__init__.py <==
from urllib.parse import urlparse
from urllib.request import urlopen, Request
import base64
import json
import ssl
import sys


class Redfish(object):
    def __init__(self, url, user='root', password='calvin', insecure=True, model='dell'):
        self.model = model.lower()
        self.cdpath = '2' if self.model in ['hp', 'hpe', 'supermicro'] else 'Cd'
        if not url.startswith('http'):
            if self.model in ['hp', 'hpe', 'supermicro']:
                self.url = f"https://{url}/redfish/v1/Systems/1"
            elif self.model == 'dell':
                self.url = f"https://{url}/redfish/v1/Systems/System.Embedded.1"
            else:
                print(f"Invalid url {url}")
                sys.exit(0)
        else:
            self.url = url
        self.user = user
        self.password = password
        self.headers = {'Content-Type': 'application/json', 'Accept': 'application/json'}
        credentials = base64.b64encode(bytes(f'{user}:{password}', 'ascii')).decode('utf-8')
        self.headers["Authorization"] = f"Basic {credentials}"
        p = urlparse(self.url)
        self.baseurl = f"{p.scheme}://{p.netloc}"
        self.manager_url = None
        self.context = ssl.create_default_context()
        if insecure:
            self.context.check_hostname = False
            self.context.verify_mode = ssl.CERT_NONE

    def get_manager_url(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return f"{self.baseurl}{response['Links']['ManagedBy'][0]['@odata.id']}"

    def get_iso_status(self):
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}", headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return f"{response['Inserted']}"

    def eject_iso(self):
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}/Actions/VirtualMedia.EjectMedia",
                          headers=self.headers, method='POST')
        urlopen(request, context=self.context)

    def insert_iso(self, iso_url):
        data = {"Image": iso_url, "Inserted": True}
        data = json.dumps(data).encode('utf-8')
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}/Actions/VirtualMedia.InsertMedia", data=data,
                          headers=self.headers)
        urlopen(request, context=self.context)

    def set_iso_once(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        data = {"Boot": {}}
        if response['Boot']['BootSourceOverrideEnabled'] != 'Once':
            data['Boot']['BootSourceOverrideEnabled'] = 'Once'
        if response['Boot']['BootSourceOverrideTarget'] != 'cd':
            data['Boot']['BootSourceOverrideTarget'] = 'Cd'
        if response['Boot']['BootSourceOverrideMode'] != 'UEFI':
            data['Boot']['BootSourceOverrideMode'] = 'UEFI'
        data = json.dumps(data).encode('utf-8')
        request = Request(self.url, data=data, headers=self.headers, method='PATCH')
        urlopen(request, context=self.context)

    def restart(self):
        data = {"ResetType": "ForceRestart"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def stop(self):
        data = {"ResetType": "ForceOff"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def start(self):
        data = {"ResetType": "On"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def status(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return response['PowerState']

    def info(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return response

    def set_iso(self, iso_url):
        self.eject_iso()
        self.insert_iso(iso_url)
        self.set_iso_once()
        self.restart()

==> aicli-99.0.202205091959.202103111306-py3-none-any.whl: ailib/redfish/__init__.py <==
from urllib.parse import urlparse
from urllib.request import urlopen, Request
import base64
import json
import ssl
import sys


class Redfish(object):
    def __init__(self, url, user='root', password='calvin', insecure=True, model='dell'):
        self.model = model.lower()
        self.cdpath = '2' if self.model in ['hp', 'hpe', 'supermicro'] else 'Cd'
        print(self.model, self.cdpath)
        if not url.startswith('http'):
            if self.model in ['hp', 'hpe', 'supermicro']:
                self.url = f"https://{url}/redfish/v1/Systems/1"
            elif self.model == 'dell':
                self.url = f"https://{url}/redfish/v1/Systems/System.Embedded.1"
            else:
                print(f"Invalid url {url}")
                sys.exit(0)
        else:
            self.url = url
        self.user = user
        self.password = password
        self.headers = {'Content-Type': 'application/json', 'Accept': 'application/json'}
        credentials = base64.b64encode(bytes(f'{user}:{password}', 'ascii')).decode('utf-8')
        self.headers["Authorization"] = f"Basic {credentials}"
        p = urlparse(self.url)
        self.baseurl = f"{p.scheme}://{p.netloc}"
        self.manager_url = None
        self.context = ssl.create_default_context()
        if insecure:
            self.context.check_hostname = False
            self.context.verify_mode = ssl.CERT_NONE

    def get_manager_url(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return f"{self.baseurl}{response['Links']['ManagedBy'][0]['@odata.id']}"

    def get_iso_status(self):
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}", headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return f"{response['Inserted']}"

    def eject_iso(self):
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}/Actions/VirtualMedia.EjectMedia",
                          headers=self.headers, method='POST')
        try:
            urlopen(request, context=self.context)
        except:
            pass

    def insert_iso(self, iso_url):
        data = {"Image": iso_url, "Inserted": True}
        data = json.dumps(data).encode('utf-8')
        manager_url = self.get_manager_url()
        request = Request(f"{manager_url}/VirtualMedia/{self.cdpath}/Actions/VirtualMedia.InsertMedia", data=data,
                          headers=self.headers)
        urlopen(request, context=self.context)

    def set_iso_once(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        currentboot = response['Boot']
        newboot = {}
        if currentboot['BootSourceOverrideEnabled'] != 'Once':
            newboot['BootSourceOverrideEnabled'] = 'Once'
        if currentboot['BootSourceOverrideTarget'] != 'cd':
            newboot['BootSourceOverrideTarget'] = 'Cd'
        if 'BootSourceOverrideMode' not in currentboot or currentboot['BootSourceOverrideMode'] != 'UEFI':
            newboot['BootSourceOverrideMode'] = 'UEFI'
        data = {"Boot": newboot}
        data = json.dumps(data).encode('utf-8')
        request = Request(self.url, data=data, headers=self.headers, method='PATCH')
        urlopen(request, context=self.context)

    def restart(self):
        data = {"ResetType": "ForceRestart"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def stop(self):
        data = {"ResetType": "ForceOff"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def start(self):
        data = {"ResetType": "On"}
        data = json.dumps(data).encode('utf-8')
        request = Request(f"{self.url}/Actions/ComputerSystem.Reset", data=data, headers=self.headers)
        urlopen(request, context=self.context)

    def status(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return response['PowerState']

    def info(self):
        request = Request(self.url, headers=self.headers)
        response = json.loads(urlopen(request, context=self.context).read())
        return response

    def set_iso(self, iso_url):
        self.eject_iso()
        self.insert_iso(iso_url)
        self.set_iso_once()
        self.restart()
